@@ -22,7 +22,7 @@ from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .literals import ProviderType, RepositoryAssociationState
+from .literals import ProviderTypeType, RepositoryAssociationStateType
 from .type_defs import ListRepositoryAssociationsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListRepositoryAssociationsPaginator",)
@@ -30,18 +30,18 @@ __all__ = ("ListRepositoryAssociationsPaginator",)
 
 class ListRepositoryAssociationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)[Show boto3-stubs documentation](./paginators.md#listrepositoryassociationspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)[Show boto3-stubs documentation](./paginators.md#listrepositoryassociationspaginator)
     """
 
     def paginate(
         self,
-        ProviderTypes: List[ProviderType] = None,
-        States: List[RepositoryAssociationState] = None,
+        ProviderTypes: List[ProviderTypeType] = None,
+        States: List[RepositoryAssociationStateType] = None,
         Names: List[str] = None,
         Owners: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListRepositoryAssociationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
         [Show boto3-stubs documentation](./paginators.md#listrepositoryassociationspaginator)
         """
