@@ -16,11 +16,11 @@ from datetime import datetime
 from typing import Dict, List
 
 from .literals import (
-    EncryptionOption,
-    JobState,
-    ProviderType,
-    Reaction,
-    RepositoryAssociationState,
+    EncryptionOptionType,
+    JobStateType,
+    ProviderTypeType,
+    ReactionType,
+    RepositoryAssociationStateType,
     TypeType,
 )
 
@@ -86,8 +86,8 @@ CodeReviewSummaryTypeDef = TypedDict(
         "CodeReviewArn": str,
         "RepositoryName": str,
         "Owner": str,
-        "ProviderType": ProviderType,
-        "State": JobState,
+        "ProviderType": ProviderTypeType,
+        "State": JobStateType,
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
         "Type": TypeType,
@@ -104,8 +104,8 @@ CodeReviewTypeDef = TypedDict(
         "CodeReviewArn": str,
         "RepositoryName": str,
         "Owner": str,
-        "ProviderType": ProviderType,
-        "State": JobState,
+        "ProviderType": ProviderTypeType,
+        "State": JobStateType,
         "StateReason": str,
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
@@ -180,7 +180,7 @@ KMSKeyDetailsTypeDef = TypedDict(
     "KMSKeyDetailsTypeDef",
     {
         "KMSKeyId": str,
-        "EncryptionOption": EncryptionOption,
+        "EncryptionOption": EncryptionOptionType,
     },
     total=False,
 )
@@ -261,7 +261,7 @@ RecommendationFeedbackSummaryTypeDef = TypedDict(
     "RecommendationFeedbackSummaryTypeDef",
     {
         "RecommendationId": str,
-        "Reactions": List[Reaction],
+        "Reactions": List[ReactionType],
         "UserId": str,
     },
     total=False,
@@ -272,7 +272,7 @@ RecommendationFeedbackTypeDef = TypedDict(
     {
         "CodeReviewArn": str,
         "RecommendationId": str,
-        "Reactions": List[Reaction],
+        "Reactions": List[ReactionType],
         "UserId": str,
         "CreatedTimeStamp": datetime,
         "LastUpdatedTimeStamp": datetime,
@@ -308,8 +308,8 @@ RepositoryAssociationSummaryTypeDef = TypedDict(
         "AssociationId": str,
         "Name": str,
         "Owner": str,
-        "ProviderType": ProviderType,
-        "State": RepositoryAssociationState,
+        "ProviderType": ProviderTypeType,
+        "State": RepositoryAssociationStateType,
     },
     total=False,
 )
@@ -322,8 +322,8 @@ RepositoryAssociationTypeDef = TypedDict(
         "ConnectionArn": str,
         "Name": str,
         "Owner": str,
-        "ProviderType": ProviderType,
-        "State": RepositoryAssociationState,
+        "ProviderType": ProviderTypeType,
+        "State": RepositoryAssociationStateType,
         "StateReason": str,
         "LastUpdatedTimeStamp": datetime,
         "CreatedTimeStamp": datetime,
